# UTF-8 encoded Serbian translation file for use with Oddmuse
#
# Copyright (c) 2003  Unknown
# Copyright (c) 2003  Chusslove Illich
#
# Permission is granted to copy, distribute and/or modify this document
# under the terms of the GNU Free Documentation License, Version 1.2
# or any later version published by the Free Software Foundation;
# with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
# A copy of the license could be found at: http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: serbian-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Читање није дозвољено: приступ за корисника, IP број или мрежу је блокиран.
Could not create %s
Не могу да направим %s
Invalid UserName %s: not saved.
Неисправно корисничко име %s: није снимљено.
UserName must be 50 characters or less: not saved
Корисничко име мора имати 50 или мање знакова: није снимљено.
This page contains an uploaded file:

XML::RSS is not available on this system.

diff

history
историјат
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

Invalid action parameter %s
Неисправан параметар акције %s
Invalid URL.
Неисправан URL.
Page name is missing

Page name is too long: %s
Име странице је предугачко: %s
Invalid Page %s
Неисправна страница %s
Invalid Page %s (must not end with .db)
Неисправна страница %s (не сме имати наставак .db)
Invalid Page %s (must not end with .lck)
Неисправна страница %s (не сме имати наставак .lck)
Page name may not contain space characters: %s
Име странице не може садржати размаке: %s
Preview:
Преглед:
Preview only, not yet saved
Ово је само преглед, измена још увек није записана
Please go on to %s.
Настави до %s.
Could not open %s log file
Нисам могао да отворим дневничку датотеку %s
Error was
Грешка
Note: This error is normal if no changes have been made.
Пажња: Ова грешка је уобичајена уколико ништа нисте изменили.
Could not open old %s log file
Нисам могао да отворим стару дневничку датотеку %s
No updates since %s
Нема измена од %s
Updates since %s
Измене од %s
Updates in the last %s days
Измене у последњих %s дана
Updates in the last %s day
Измене у последњи %s дан
for %s only
само за %s
List latest change per page only

List all changes

List only major changes

Include minor changes

%s days
%s дана
List later changes

Filters

Username:
Корисничко име:
Host:

Language:

Go!
Иди!
(minor)
(ситна)
rollback
повратак
new

from %s
од %s
History of %s
Историјат за %s
Compare
Упореди
Revision %s
Верзија %s
by
—
Rolling back changes
Враћам измене
Missing target for rollback.
Недостаје циљ за повратак.
Target for rollback is too far back.
Циљ за повратак је предалеко уназад.
Rollback to %s
Повратак на %s
%s rolled back
%s је враћен
Index of all pages
Списак свих страна:
Wiki Version
Приказујем верзију Викија
Unlock Wiki
Откључавам
Recent Visitors
Скори посетиоци
Password
Лозинка
Run maintenance

Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Кућа]
redirected from %s
преусмерено са %s
Click to search for references to this page

Cookie: 
Колачић: 
Warning
Упозорење
Database is stored in temporary directory %s
База је снимљена у привремени директоријум %s
%s seconds
%s секунди
The same page on other sites:

EditNearLinks

Last edited
Последње уређивање
Edited
Уређено
by %s
— %s
(diff)
(разлике)
Edit revision %s of this page
Уреди верзију %s ове странице
Edit this page
Уреди текст ове странице
e

This page is read-only
Ова страница је само за читање
View other revisions
Прикажи остале верзије
View current revision
Прикажи тренутну верзију
View all changes
Прикажи све измене
new comment
нови коментар
Homepage URL:

s

Save
Сачувај
Preview
Преглед
Search:
Пронађи:
f

Replace:
Замени:
Validate HTML
Провери HTML
Validate CSS
Провери CSS
Difference (from revision %1 to %2)

revision %s
верзија %s
current revision
текућа верзија
Difference (from prior %s revision)
Разлика (текућа верзија у односу на претходну - %s)
major
крупна
minor
ситна
No diff available.
Разлика није доступна.
Old revision:

Changed:
Измењено:
Removed:
Уклоњено:
Added:
Додато:
to
у
Revision %s not available
Верзија %s није доступна
showing current revision instead
уместо тога, користи се тренутна верзија
Showing revision %s
Приказана верзија %s
Cannot save a nameless page.
Не могу да снимим безимену страну.
Cannot save a page without revision.

Cannot open %s

Cannot write %s

Could not get %s lock
Нисам могао да добавим браву %s
This operation may take several seconds...
Ова операција може потрајати неколико секунди...
Forced unlock of %s lock.
Форсирано откључавање браве %s.
No unlock required.
Откључавање није неопходно.
%s hours ago
пре %s часова
1 hour ago
пре 1 часа
%s minutes ago
пре %s минута
1 minute ago
пре 1 минута
%s seconds ago
пре %s секунди
1 second ago
пре 1 секунде
just now
управо сада
Editing Denied
Уређивање је одбијено
Editing not allowed: user, ip, or network is blocked.
Уређивање није дозвољено: приступ за корисника, IP број или мрежу је блокиран.
Contact the wiki administrator for more information.
Обратите се администратору за више информација.
The rule %s matched for you.

See %s for more information.
Погледајте %s за више информација.
Editing not allowed: %s is read-only.
Уређивање није дозвољено: %s је само за читање.
Only administrators can upload files.
Само администратори могу да каче датотеке.
Editing revision %s of
Уређује се верзија %s
Editing %s
Уређивање %s
Editing old revision %s.
Уређивање старе верзије %s.
Saving this page will replace the latest revision with this text.
Снимање ове странице ће преписати последњу верзију новим текстом.
Summary:
Сажетак:
This change is a minor edit.
Ово је ситна измена.
Replace this file with text.
Замени ову датотеку текстом.
Replace this text with a file.
Замени овај текст датотеком.
File to upload: 
Датотека коју треба окачити: 
Files of type %s are not allowed.
Датотеке типа %s нису дозвољене.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваша лозинка је снимљена у колачићу, ако су укључени. Колачићи могу бити изгубљени ако се повежете са друге машине, са другог налога, или користећи други програм.
You are currently an administrator on this site.
Тренутно сте администратор на овом сајту.
You are currently an editor on this site.
Тренутно сте уредник на овом сајту.
You are a normal user on this site.
Ви сте нормални корисник на овом сајту.
Your password does not match any of the  administrator or editor passwords.
Ваша лозинка се не поклапа ни са једном од аминистраторских или уредничких лозинки.
Password:
Лозинка:
This site does not use admin or editor passwords.
Овај сајт не користи администраторске или уредничке лозинке.
This operation is restricted to site editors only...
Ово смеју да раде само уредници сајта...
This operation is restricted to administrators only...
Ово сме да ради само администратор...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

%s pages found.

Replaced: %s
Замењено: %s
Search for: %s
Тражи: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
последњи пут ажурирана
Complete Content
Потпуни садржај
The main page is %s.
Главна страна је %s.
Comments on this page
Коментари на овој страни
Editing not allowed for %s.
Уређивање није дозвољено за %s.
SampleUndefinedPage
НенаписанаСтраницаЗаПример
%s cannot be defined.
%s се не може дефинисати.
Sample_Undefined_Page
Ненаписана_Страница_За_Пример
[[%s]] cannot be defined.
[[%s]] се не може дефинисати.
Only an administrator can create %s.

Transfer Error: %s
Грешка у преносу: %s
Browser reports no file info.
Прегледач не пријављује информације о датотеци.
Browser reports no file type.
Прегледач не пријављује тип датотеке.
Edit Denied

The page contains banned text.

This page was changed by somebody else %s.
Ову страницу је изменио неко други %s.
The changes conflict.  Please check the page again.
Измене су у сукобу. Проверите страну поново.
Please check whether you overwrote those changes.
Проверите да нисте пребрисали ове те измене.
Anonymous
Анонимони
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
Нисам могао да добавим браву за стапање!
you
ви
ancestor
предак
other
други
Run Maintenance

Maintenance not done.
Одржавање није урађено.
(Maintenance can only be done once every 12 hours.)
(Одржавање може да се уради једном сваких 13 часова.)
Remove the "maintain" file or wait.
Уклони датотеку одржавања или чекај.
Main lock obtained.
Главна брава је добављена.
Expiring keep files and deleting pages marked for deletion
Истичем датотеке чувања и бришем странице означене за брисање
not deleted: 

deleted
обрисано
Moving part of the %s log file.
Премештам део дневничке датотеке %s.
Moving %s log entries.
Премештам %s дневничких ставки.
Getting page index file for %s.

Main lock released.
Главна брава је отпуштена.
Set or Remove global edit lock
Постави или уклони глобалну браву за уређивање
Edit lock created.
Брава за уређивање је направљена.
Edit lock removed.
Брава за уређивање је уклоњена.
Set or Remove page edit lock
Постави или уклони браву за уређивање стране
Missing page id to lock/unlock...
Недостаје ид. стране коју треба откључати/закључати
Lock for %s created.
Брава за %s је направљена.
Lock for %s removed.
Брава за %s је уклоњена.
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Превише веза од %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s
сидро је прво дефинисано овде: %s
Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Footnotes:

Could not find %1.html template in %2

image: %s

Index

Languages:

Show!

Define

Full Link List
Потпуни списак веза
Template without parameters

The template %s is either empty or does not exist.

%s returned no data.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers
Све референце
Referrers
Референце
Updating %s

Search term missing.

Static Copy

Back to %s

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
други
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
претрага
Blog

END_OF_TRANSLATION
